==> danse-2.2.0.tar.gz: danse/modules/content/src/Payload.php <==
<?php

namespace Drupal\danse_content;

use Drupal\comment\CommentInterface;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;
use Drupal\danse_content\Topic\TopicInterface;
use Drupal\user\Entity\User;

/**
 * Class Payload.
 *
 * @package Drupal\danse_content
 */
final class Payload extends PayloadBase {

  /**
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  protected $entity;

  /**
   * Content constructor.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   */
  public function __construct(ContentEntityInterface $entity) {
    $this->entity = $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    return $this->entity->label();
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', [$this->entity->getEntityTypeId(), $this->entity->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    $plugin = $event->getPlugin();
    $topic = $event->getTopic();
    $references = [];

    // Subscription to entity type.
    $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->bundle(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY_TYPE, $topic);

    // Subscription to individual entity.
    $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->id(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);

    if ($this->entity instanceof CommentInterface) {

      // Subscription to comments of individual entity.
      $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);

      // Subscriptions to comment parents.
      $comment = $this->entity;
      while ($comment = $comment->getParentComment()) {
        $references[] = $plugin->subscriptionKey($comment->getEntityTypeId(), $comment->id(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);
      }
      // Subscriptions to commented entity.
      $comment = $this->entity;
      $references[] = $plugin->subscriptionKey($comment->getCommentedEntityTypeId(), $comment->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, TopicInterface::COMMENT);
      $references[] = $plugin->subscriptionKey($comment->getCommentedEntityTypeId(), $comment->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY_TYPE, TopicInterface::COMMENT);
    }

    // Subscription to related content.
    foreach ($this->entity->getFieldDefinitions() as $fieldName => $fieldDefinition) {
      if ($fieldDefinition->getType() === 'entity_reference') {
        foreach ($this->entity->get($fieldName)->referencedEntities() as $referencedEntity) {
          $references[] = $plugin->subscriptionKey($referencedEntity->getEntityTypeId(), $referencedEntity->id(), SubscriptionOperation::SUBSCRIPTION_MODE_RELATED_ENTITY, $topic);
        }
      }
    }

    return $references;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'entity' => [
        'type' => $this->entity->getEntityTypeId(),
        'bundle' => $this->entity->bundle(),
        'id' => $this->entity->id(),
        'label' => $this->entity->label(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): PayloadInterface {
    try {
      $storage = \Drupal::entityTypeManager()->getStorage($payload['entity']['type']);
    }
    catch (InvalidPluginDefinitionException $e) {
    }
    catch (PluginNotFoundException $e) {
    }
    /** @noinspection IsEmptyFunctionUsageInspection */
    if (empty($storage)) {
      // Entity type does not exist anymore, created a dummy entity and don't save it.
      $entity = Event::create([
        'label' => 'Content type ' . $payload['entity']['type'] . ' no longer exists.',
      ]);
    }
    else {
      /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
      $entity = $storage->load($payload['entity']['id']);
      if (empty($entity)) {
        // Entity got deleted, created a dummy entity and don't save it.
        $entity = $storage->create([
          $storage->getEntityType()->getKey('bundle') => $payload['entity']['bundle'],
          $storage->getEntityType()->getKey('id') => $payload['entity']['id'],
          $storage->getEntityType()->getKey('label') => $payload['entity']['label'],
        ]);
      }
    }
    return new static($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    /** @var \Drupal\user\UserInterface $user */
    $user = User::load($uid);
    return $this->getEntity()->access('view', $user);
  }

}

==> danse-2.2.7.tar.gz: danse/modules/content/src/Payload.php <==
<?php

namespace Drupal\danse_content;

use Drupal\comment\CommentInterface;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;
use Drupal\danse_content\Topic\TopicInterface;
use Drupal\user\Entity\User;

/**
 * Class Payload.
 *
 * @package Drupal\danse_content
 */
final class Payload extends PayloadBase {

  /**
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  protected $entity;

  /**
   * Content constructor.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   */
  public function __construct(ContentEntityInterface $entity) {
    $this->entity = $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function label(Event $event): string {
    return $this->entity->label();
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', [$this->entity->getEntityTypeId(), $this->entity->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    $plugin = $event->getPlugin();
    $topic = $event->getTopic();
    $references = [];

    // Subscription to entity type.
    $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->bundle(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY_TYPE, $topic);

    // Subscription to individual entity.
    $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->id(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);

    if ($this->entity instanceof CommentInterface) {

      // Subscription to comments of individual entity.
      $references[] = $plugin->subscriptionKey($this->entity->getEntityTypeId(), $this->entity->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);

      // Subscriptions to comment parents.
      $comment = $this->entity;
      while ($comment = $comment->getParentComment()) {
        $references[] = $plugin->subscriptionKey($comment->getEntityTypeId(), $comment->id(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, $topic);
      }
      // Subscriptions to commented entity.
      $comment = $this->entity;
      $references[] = $plugin->subscriptionKey($comment->getCommentedEntityTypeId(), $comment->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY, TopicInterface::COMMENT);
      $references[] = $plugin->subscriptionKey($comment->getCommentedEntityTypeId(), $comment->getCommentedEntityId(), SubscriptionOperation::SUBSCRIPTION_MODE_ENTITY_TYPE, TopicInterface::COMMENT);
    }

    // Subscription to related content.
    foreach ($this->entity->getFieldDefinitions() as $fieldName => $fieldDefinition) {
      if ($fieldDefinition->getType() === 'entity_reference') {
        foreach ($this->entity->get($fieldName)->referencedEntities() as $referencedEntity) {
          $references[] = $plugin->subscriptionKey($referencedEntity->getEntityTypeId(), $referencedEntity->id(), SubscriptionOperation::SUBSCRIPTION_MODE_RELATED_ENTITY, $topic);
        }
      }
    }

    return $references;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'entity' => [
        'type' => $this->entity->getEntityTypeId(),
        'bundle' => $this->entity->bundle(),
        'id' => $this->entity->id(),
        'label' => $this->entity->label(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    try {
      $storage = \Drupal::entityTypeManager()->getStorage($payload['entity']['type']);
      /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
      $entity = $storage->load($payload['entity']['id']);
      if ($entity === NULL) {
        // Entity got deleted, created a dummy entity and don't save it.
        $entity = $storage->create([
          $storage->getEntityType()->getKey('bundle') => $payload['entity']['bundle'],
          $storage->getEntityType()->getKey('id') => $payload['entity']['id'],
          $storage->getEntityType()->getKey('label') => $payload['entity']['label'],
        ]);
      }
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      // Entity type does not exist, create a dummy entity and don't save it.
      $entity = Event::create([
        'label' => 'Content type ' . $payload['entity']['type'] . ' no longer exists.',
      ]);
    }
    return new Payload($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    /** @var \Drupal\user\UserInterface $user */
    $user = User::load($uid);
    return $this->getEntity()->access('view', $user);
  }

}
